Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildRegistry ¶
func BuildRegistry()
Types ¶
type Deserializer ¶
Deserializer can parse a serialized string back to an object
func MakeDeserializer ¶
func MakeDeserializer() Deserializer
MakeDeserializer creates the default deserializer
type InteractiveSerializer ¶
type InteractiveSerializer interface {
Serializer
Reset()
}
InteractiveSerializer can gradually serialize the whole data tree.
func NewInteractiveSerializer ¶
func NewInteractiveSerializer() InteractiveSerializer
NewInteractiveSerializer returns a new InteractiveSerializer
type Serializer ¶
Serializer can serialize anything into a json format
type TypeRegistry ¶
TypeRegistry keeps track of all the types available in the current application.
The TypeRegistry implementation is following this answer on stackoverflow. https://stackoverflow.com/a/34722791/1709930
func GetTypeRegistry ¶
func GetTypeRegistry() TypeRegistry
GetTypeRegistry get the singleton instance of the TypeRegistry
Source Files
¶
Click to show internal directories.
Click to hide internal directories.